@@ -35,6 +35,8 @@
 
 #include <cstdio>
 #include <cmath>
+#include <climits>
+
 #include <sys/types.h>
 
 #ifdef WIN32
@@ -50,9 +52,10 @@
 #include <sstream>
 #include <algorithm>
 #include <functional>
+#include <memory>
 
 // #define DODS_DEBUG
-//#define DODS_DEBUG2
+// #define DODS_DEBUG2
 
 #include "GNURegex.h"
 
@@ -60,11 +63,14 @@
 #include "Clause.h"
 #include "Error.h"
 #include "InternalErr.h"
+#if 0
 #include "Keywords2.h"
+#endif
 
 #include "parser.h"
 #include "debug.h"
 #include "util.h"
+#include "DapIndent.h"
 
 #include "Byte.h"
 #include "Int16.h"
@@ -83,14 +89,9 @@
 #include "escaping.h"
 
 /**
- * ############################################################################################
- * ############################################################################################
- * ############################################################################################
  * DapXmlNamespaces
  *
- * FIXME Replace all usages of the following variable with calls to DapXmlNamespaces
- * TODO  Replace all usages of the following variable with calls to DapXmlNamespaces
- *
+ * @todo Replace all usages of the following variable with calls to DapXmlNamespaces
  */
 const string c_xml_xsi = "http://www.w3.org/2001/XMLSchema-instance";
 const string c_xml_namespace = "http://www.w3.org/XML/1998/namespace";
@@ -108,15 +109,11 @@ const string c_dap40_namespace = "http://xml.opendap.org/ns/DAP/4.0#";
 const string c_dap_20_n_sl = c_dap20_namespace + " " + c_default_dap20_schema_location;
 const string c_dap_32_n_sl = c_dap32_namespace + " " + c_default_dap32_schema_location;
 const string c_dap_40_n_sl = c_dap40_namespace + " " + c_default_dap40_schema_location;
-/**
- *
- * DapXmlNamespaces
- * ############################################################################################
- * ############################################################################################
- * ############################################################################################
- */
-
 
+/// Name given to a container for orphaned top-level attributes.
+/// These can show up when a DAS is built from a DMR because DAP4
+/// supports attributes at the top level that are not in any container.
+const string TOP_LEVEL_ATTRS_CONTAINER_NAME = "DAP4_GLOBAL";
 
 using namespace std;
 
@@ -185,7 +182,9 @@ DDS::duplicate(const DDS &dds)
 
     d_timeout = dds.d_timeout;
 
+#if 0
     d_keywords = dds.d_keywords; // value copy; Keywords contains no pointers
+#endif
 
     d_max_response_size = dds.d_max_response_size;
 }
@@ -205,7 +204,7 @@ DDS::duplicate(const DDS &dds)
 DDS::DDS(BaseTypeFactory *factory, const string &name)
         : d_factory(factory), d_name(name), d_container_name(""), d_container(0),
           d_request_xml_base(""),
-          d_timeout(0), d_keywords(), d_max_response_size(0)
+          d_timeout(0), /*d_keywords(),*/ d_max_response_size(0)
 {
     DBG(cerr << "Building a DDS for the default version (2.0)" << endl);
 
@@ -232,7 +231,7 @@ DDS::DDS(BaseTypeFactory *factory, const string &name)
 DDS::DDS(BaseTypeFactory *factory, const string &name, const string &version)
         : d_factory(factory), d_name(name), d_container_name(""), d_container(0),
           d_request_xml_base(""),
-          d_timeout(0), d_keywords(), d_max_response_size(0)
+          d_timeout(0), /*d_keywords(),*/ d_max_response_size(0)
 {
     DBG(cerr << "Building a DDS for version: " << version << endl);
 
@@ -615,11 +614,6 @@ DDS::add_var_nocopy(BaseType *bt)
 {
     if (!bt)
         throw InternalErr(__FILE__, __LINE__, "Trying to add a BaseType object with a NULL pointer.");
-#if 0
-    //FIXME There's no longer a DAP2 and DAP4 DDS
-    if (bt->is_dap4_only_type())
-        throw InternalErr(__FILE__, __LINE__, "Attempt to add a DAP4 type to a DAP2 DDS.");
-#endif
 
     DBG2(cerr << "In DDS::add_var(), bt's address is: " << bt << endl);
 
@@ -1048,6 +1042,75 @@ DDS::print(ostream &out)
     return ;
 }
 
+/**
+ * Does this AttrTable have descendants that are scalar or vector attributes?
+ *
+ * @param a The AttrTable
+ * @return true if the table contains a scalar- or vector-valued attribute,
+ * otherwise false.
+ */
+bool
+has_dap2_attributes(AttrTable &a)
+{
+    for (AttrTable::Attr_iter i = a.attr_begin(), e = a.attr_end(); i != e; ++i) {
+        if (a.get_attr_type(i) != Attr_container) {
+            return true;
+        }
+        else if (has_dap2_attributes(*a.get_attr_table(i))) {
+            return true;
+        }
+    }
+
+    return false;
+
+#if 0
+    vector<AttrTable*> tables;
+
+    for (AttrTable::Attr_iter i = a.attr_begin(), e = a.attr_end(); i != e; ++i) {
+        if (a.get_attr_type(i) != Attr_container)
+        return true;
+        else
+        tables.push_back(a.get_attr_table(i));
+    }
+
+    bool it_does = false;
+    for (vector<AttrTable*>::iterartor i = tables.begin(), e = tables.end(); it_does || i != e; ++i) {
+        it_does = has_dap2_attributes(**i);
+    }
+
+    return it_does;
+#endif
+}
+
+/**
+ * Does this variable, or any of its descendants, have attributes?
+ *
+ * @param btp The variable
+ * @return True if any of the variable's descendants have attributes,
+ * otherwise false.
+ */
+bool
+has_dap2_attributes(BaseType *btp)
+{
+    if (btp->get_attr_table().get_size() && has_dap2_attributes(btp->get_attr_table())) {
+        return true;
+    }
+
+    Constructor *cons = dynamic_cast<Constructor *>(btp);
+    if (cons) {
+        Grid* grid = dynamic_cast<Grid*>(btp);
+        if(grid){
+            return has_dap2_attributes(grid->get_array());
+        }
+        else {
+            for (Constructor::Vars_iter i = cons->var_begin(), e = cons->var_end(); i != e; i++) {
+                if (has_dap2_attributes(*i)) return true;
+            }
+        }
+    }
+    return false;
+}
+
 /**
  * Print the DAP2 DAS object using attribute information recorded
  * this DDS object.
@@ -1058,35 +1121,201 @@ DDS::print(ostream &out)
  * @param out Write the DAS here.
  */
 static string four_spaces = "    ";
-void print_var_das(ostream &out, BaseType *bt, string indent=""){
+void print_var_das(ostream &out, BaseType *bt, string indent = "") {
+
+    if (!has_dap2_attributes(bt))
+        return;
 
     AttrTable attr_table = bt->get_attr_table();
     out << indent << add_space_encoding(bt->name()) << " {" << endl;
-    attr_table.print(out, indent+four_spaces);
-    Constructor *cnstrctr = dynamic_cast < Constructor * >(bt);
-    if(cnstrctr) {
-        Constructor::Vars_iter i = cnstrctr->var_begin();
-        Constructor::Vars_iter e = cnstrctr->var_end();
-        for (; i!=e; i++) {
-            print_var_das(out,*i,indent+four_spaces);
+
+    Constructor *cnstrctr = dynamic_cast<Constructor *>(bt);
+    if (cnstrctr) {
+        Grid *grid = dynamic_cast<Grid *>(bt);
+        if (grid) {
+            Array *gridArray = grid->get_array();
+            AttrTable arrayAT = gridArray->get_attr_table();
+
+            if (has_dap2_attributes(gridArray))
+                gridArray->get_attr_table().print(out, indent + four_spaces);
+#if 0
+            // I dropped this because we don't want the MAP vectors showing up in the DAS
+            // as children of a Grid (aka flatten the Grid bro) - ndp 5/25/18
+            for (Grid::Map_iter mIter = grid->map_begin();
+                    mIter != grid->map_end(); ++mIter) {
+                BaseType *currentMap = *mIter;
+                if (has_dap2_attributes(currentMap))
+                    print_var_das(out, currentMap, indent + four_spaces);
+            }
+#endif
+        }
+        else {
+            attr_table.print(out, indent + four_spaces);
+            Constructor::Vars_iter i = cnstrctr->var_begin();
+            Constructor::Vars_iter e = cnstrctr->var_end();
+            for (; i != e; i++) {
+                // Only call print_var_das() if there really are attributes.
+                // This is made complicated because while there might be none
+                // for a particular var (*i), that var might be a ctor and its
+                // descendant might have an attribute. jhrg 3/18/18
+                if (has_dap2_attributes(*i))
+                    print_var_das(out, *i, indent + four_spaces);
+            }
         }
-
     }
-    out << indent << "}" << endl;
+    else {
+        attr_table.print(out, indent + four_spaces);
+    }
 
+    out << indent << "}" << endl;
 }
 
+/**
+ * @brief write the DAS response given the attribute information in the DDS
+ *
+ * This method provides the same DAS response as DAS::print(), but does so
+ * using the AttrTables bound to the variables in this DDS object.
+ *
+ * @param out Write the DAS response to this stream
+ */
 void
 DDS::print_das(ostream &out)
 {
+#if 0
     string indent("    ");
-    out << "Attributes {" << endl ;
+    out << "Attributes {" << endl;
     for (Vars_citer i = vars.begin(); i != vars.end(); i++) {
+        if (has_dap2_attributes(*i))
         print_var_das(out, *i, four_spaces);
     }
     // Print the global attributes at the end.
     d_attr.print(out,indent);
-    out << "}" << endl ;
+    out << "}" << endl;
+#endif
+
+    auto_ptr<DAS> das(get_das());
+
+    das->print(out);
+}
+
+/**
+ * @brief Get a DAS object
+ *
+ * Returns a new DAS that contains all of the Dataset attributes. This includes all Variable
+ * attributes as well as Global attributes. The caller is responsible for deleting the
+ * returned object.
+ *
+ * @return A newly allocated DAS object
+ */
+DAS *
+DDS::get_das()
+{
+    DAS *das = new DAS();
+    get_das(das);
+    return das;
+}
+
+/**
+ * Get a suitable name for new container for top-level attributes
+ * @param das Look in this DAS to find an unused name
+ * @return The name
+ */
+static string
+get_unique_top_level_global_container_name(DAS *das)
+{
+    // It's virtually certain that the TOP_LEVE... name will be unique. If so,
+    // return the name. The code tests for a table to see if the name _should not_ be used.
+    AttrTable *table = das->get_table(TOP_LEVEL_ATTRS_CONTAINER_NAME);
+    if (!table)
+        return TOP_LEVEL_ATTRS_CONTAINER_NAME;
+
+    // ... but the default name might already be used
+    unsigned int i = 0;
+    string name;
+    ostringstream oss;
+    while (table) {
+        oss.str(""); // reset to empty for the next suffix
+        oss << "_" << ++i;
+        if (!(i < UINT_MAX))
+            throw InternalErr(__FILE__, __LINE__, "Cannot add top-level attributes to the DAS");
+        name = TOP_LEVEL_ATTRS_CONTAINER_NAME + oss.str();
+        table = das->get_table(name);
+    }
+
+    return name;
+}
+
+/**
+ * @brief Recursive helper function for Building DAS entries for
+ * Constructor types.
+ * @param at Add Constructor content to this Attribute table
+ * @param bt A pointer to a BaseType which may be an
+ * instance of Constructor.
+ */
+void fillConstructorAttrTable(AttrTable *at, BaseType *bt){
+    Constructor *cons = dynamic_cast<Constructor *>(bt);
+    if (cons) {
+        Grid *grid = dynamic_cast<Grid *>(bt);
+        if(grid){
+            Array *gridArray = grid->get_array();
+            AttrTable arrayAT = gridArray->get_attr_table();
+
+            for( AttrTable::Attr_iter atIter = arrayAT.attr_begin(); atIter!=arrayAT.attr_end(); ++atIter){
+                AttrType type = arrayAT.get_attr_type(atIter);
+                string childName = arrayAT.get_name(atIter);
+                if (type == Attr_container){
+                    at->append_container( new AttrTable(*arrayAT.get_attr_table(atIter)), childName);
+                }
+                else {
+                    vector<string>* pAttrTokens = arrayAT.get_attr_vector(atIter);
+                    // append_attr makes a copy of the vector, so we don't have to do so here.
+                    at->append_attr(childName, AttrType_to_String(type), pAttrTokens);
+                }
+            }
+
+        }
+        else {
+            for (Constructor::Vars_iter i = cons->var_begin(), e = cons->var_end(); i != e; i++) {
+                if (has_dap2_attributes(*i)) {
+                    AttrTable *childAttrT =  new AttrTable((*i)->get_attr_table());
+                    fillConstructorAttrTable(childAttrT, *i);
+                    at->append_container(childAttrT,(*i)->name());
+                }
+            }
+        }
+    }
+}
+
+void DDS::get_das(DAS *das)
+{
+    for (Vars_citer i = vars.begin(); i != vars.end(); i++) {
+        if (has_dap2_attributes(*i)) {
+            AttrTable *childAttrT =  new AttrTable((*i)->get_attr_table());
+            fillConstructorAttrTable(childAttrT, *i);
+            das->add_table((*i)->name(), childAttrT);
+        }
+    }
+
+    // Used in the rare case we have global attributes not in a table.
+    auto_ptr<AttrTable> global(new AttrTable);
+
+    for (AttrTable::Attr_iter i = d_attr.attr_begin(); i != d_attr.attr_end(); ++i) {
+        // It's possible, given the API and if the DDS was built from a DMR, that a
+        // global attribute might not be a container; check for that.
+        if (d_attr.get_attr_table(i)) {
+            das->add_table(d_attr.get_name(i), new AttrTable(*(d_attr.get_attr_table(i))));
+        }
+        else {
+            // This must be a top level attribute outside a container.  jhrg 4/6/18
+            global->append_attr(d_attr.get_name(i), d_attr.get_type(i), d_attr.get_attr_vector(i));
+        }
+    }
+
+    // if any attributes were added to 'global,' add it to the DAS and take control of the pointer.
+    if (global->get_size() > 0) {
+        das->add_table(get_unique_top_level_global_container_name(das), global.get());  // What if this name is not unique?
+        global.release();
+    }
 }
 
 /** @brief Print a constrained DDS to the specified file.
@@ -1154,7 +1383,7 @@ DDS::print_xml(FILE *out, bool constrained, const string &blob)
 }
 
 /** Print an XML representation of this DDS. This method is used to generate
-    the part of the DDX response. The \c Dataset tag is \e not written by
+    the DDX response. The \c Dataset tag is \e not written by
     this code. The caller of this method must handle writing that and
     including the \c dataBLOB tag.
 
@@ -1205,76 +1434,135 @@ DDS::print_xml_writer(ostream &out, bool constrained, const string &blob)
 {
     XMLWriter xml("    ");
 
+    // this is the old version of this method. It produced different output for
+    // different version of DAP. We stopped using version numbers and use different
+    // web api calls (DMR, DAP for DAP4 and DAS, DDS and DODS for DAP2) so the
+    // dap version numbers are old and should not be used. There also seems to
+    // be a bug where these version numbers change 'randomly' but which doesn't
+    // show up in testing (or with valgrind or asan). jhrg 9/10/18
+#if 0
     // Stamp and repeat for these sections; trying to economize is makes it
     // even more confusing
     if (get_dap_major() >= 4) {
         if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "Group") < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write Group element");
+        throw InternalErr(__FILE__, __LINE__, "Could not write Group element");
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)d_name.c_str()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for name");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for name");
 
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "dapVersion", (const xmlChar*)get_dap_version().c_str()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for dapVersion");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for dapVersion");
 
         if (!get_request_xml_base().empty()) {
             if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns:xml", (const xmlChar*)c_xml_namespace.c_str()) < 0)
-                throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:xml");
+            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:xml");
 
             if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xml:base", (const xmlChar*)get_request_xml_base().c_str()) < 0)
-                throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xml:base");
+            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xml:base");
         }
         if (!get_namespace().empty()) {
             if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns", (const xmlChar*)get_namespace().c_str()) < 0)
-                throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns");
+            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns");
         }
     }
     else if (get_dap_major() == 3 && get_dap_minor() >= 2) {
         if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "Dataset") < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write Dataset element");
+        throw InternalErr(__FILE__, __LINE__, "Could not write Dataset element");
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)d_name.c_str()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for name");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for name");
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns:xsi", (const xmlChar*)"http://www.w3.org/2001/XMLSchema-instance") < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:xsi");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:xsi");
 
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xsi:schemaLocation", (const xmlChar*)c_dap_32_n_sl.c_str()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:schemaLocation");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:schemaLocation");
 
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns:grddl", (const xmlChar*)"http://www.w3.org/2003/g/data-view#") < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:grddl");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:grddl");
 
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "grddl:transformation", (const xmlChar*)grddl_transformation_dap32.c_str()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:transformation");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:transformation");
 
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns", (const xmlChar*)c_dap32_namespace.c_str()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns");
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns:dap", (const xmlChar*)c_dap32_namespace.c_str()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:dap");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:dap");
 
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "dapVersion", (const xmlChar*)"3.2") < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for dapVersion");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for dapVersion");
 
         if (!get_request_xml_base().empty()) {
             if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns:xml", (const xmlChar*)c_xml_namespace.c_str()) < 0)
-                throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:xml");
+            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:xml");
 
             if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xml:base", (const xmlChar*)get_request_xml_base().c_str()) < 0)
-                throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xml:base");
+            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xml:base");
         }
     }
     else { // dap2
         if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "Dataset") < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write Dataset element");
+        throw InternalErr(__FILE__, __LINE__, "Could not write Dataset element");
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)d_name.c_str()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns:xsi", (const xmlChar*)"http://www.w3.org/2001/XMLSchema-instance") < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:xsi");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:xsi");
 
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns", (const xmlChar*)c_dap20_namespace.c_str()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns");
 
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xsi:schemaLocation", (const xmlChar*)c_dap_20_n_sl.c_str()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:schemaLocation");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:schemaLocation");
     }
+#endif
+
+#if DAP2_DDX
+    if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "Dataset") < 0)
+    throw InternalErr(__FILE__, __LINE__, "Could not write Dataset element");
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)d_name.c_str()) < 0)
+    throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns:xsi", (const xmlChar*)"http://www.w3.org/2001/XMLSchema-instance") < 0)
+    throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:xsi");
+
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns", (const xmlChar*)c_dap20_namespace.c_str()) < 0)
+    throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns");
+
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xsi:schemaLocation", (const xmlChar*)c_dap_20_n_sl.c_str()) < 0)
+    throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:schemaLocation");
+#elif DAP3_2_DDX
+    // This is the 'DAP 3.2' DDX response - now the only response libdap will return.
+    // jhrg 9/10/18
+    if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "Dataset") < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not write Dataset element");
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "name", (const xmlChar*)d_name.c_str()) < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for name");
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns:xsi", (const xmlChar*)"http://www.w3.org/2001/XMLSchema-instance") < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:xsi");
+
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xsi:schemaLocation", (const xmlChar*)c_dap_32_n_sl.c_str()) < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:schemaLocation");
+
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns:grddl", (const xmlChar*)"http://www.w3.org/2003/g/data-view#") < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:grddl");
+
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "grddl:transformation", (const xmlChar*)grddl_transformation_dap32.c_str()) < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:transformation");
+
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns", (const xmlChar*)c_dap32_namespace.c_str()) < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns");
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns:dap", (const xmlChar*)c_dap32_namespace.c_str()) < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:dap");
+
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "dapVersion", (const xmlChar*)"3.2") < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for dapVersion");
+
+    if (!get_request_xml_base().empty()) {
+        if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xmlns:xml", (const xmlChar*)c_xml_namespace.c_str()) < 0)
+            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xmlns:xml");
+
+        if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "xml:base", (const xmlChar*)get_request_xml_base().c_str()) < 0)
+            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for xml:base");
+    }
+#else
+#error Must define DAP2_DDX or DAP3_2_DDX
+#endif
 
     // Print the global attributes
     d_attr.print_xml_writer(xml);
@@ -1282,6 +1570,9 @@ DDS::print_xml_writer(ostream &out, bool constrained, const string &blob)
     // Print each variable
     for_each(var_begin(), var_end(), VariablePrintXMLWriter(xml, constrained));
 
+    // As above, this method now onl returns the DAP 3.2 version of the DDX response.
+    // jhrg 9/10/28
+#if 0
     // For DAP 3.2 and greater, use the new syntax and value. The 'blob' is
     // the CID of the MIME part that holds the data. For DAP2 (which includes
     // 3.0 and 3.1), the blob is an href. For DAP4, only write the CID if it's
@@ -1289,41 +1580,62 @@ DDS::print_xml_writer(ostream &out, bool constrained, const string &blob)
     if (get_dap_major() >= 4) {
         if (!blob.empty()) {
             if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "blob") < 0)
-                throw InternalErr(__FILE__, __LINE__, "Could not write blob element");
+            throw InternalErr(__FILE__, __LINE__, "Could not write blob element");
             string cid = "cid:" + blob;
             if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "href", (const xmlChar*) cid.c_str()) < 0)
-                throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
+            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
             if (xmlTextWriterEndElement(xml.get_writer()) < 0)
-                throw InternalErr(__FILE__, __LINE__, "Could not end blob element");
+            throw InternalErr(__FILE__, __LINE__, "Could not end blob element");
         }
     }
     else if (get_dap_major() == 3 && get_dap_minor() >= 2) {
         if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "blob") < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write blob element");
+        throw InternalErr(__FILE__, __LINE__, "Could not write blob element");
         string cid = "cid:" + blob;
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "href", (const xmlChar*) cid.c_str()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
         if (xmlTextWriterEndElement(xml.get_writer()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not end blob element");
+        throw InternalErr(__FILE__, __LINE__, "Could not end blob element");
     }
     else { // dap2
         if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "dataBLOB") < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write dataBLOB element");
+        throw InternalErr(__FILE__, __LINE__, "Could not write dataBLOB element");
         if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "href", (const xmlChar*) "") < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
         if (xmlTextWriterEndElement(xml.get_writer()) < 0)
-            throw InternalErr(__FILE__, __LINE__, "Could not end dataBLOB element");
+        throw InternalErr(__FILE__, __LINE__, "Could not end dataBLOB element");
     }
+#endif
+
+#if DAP2_DDX
+    if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "dataBLOB") < 0)
+    throw InternalErr(__FILE__, __LINE__, "Could not write dataBLOB element");
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "href", (const xmlChar*) "") < 0)
+    throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
+    if (xmlTextWriterEndElement(xml.get_writer()) < 0)
+    throw InternalErr(__FILE__, __LINE__, "Could not end dataBLOB element");
+#elif DAP3_2_DDX
+    if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "blob") < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not write blob element");
+    string cid = "cid:" + blob;
+    if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "href", (const xmlChar*) cid.c_str()) < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
+    if (xmlTextWriterEndElement(xml.get_writer()) < 0)
+        throw InternalErr(__FILE__, __LINE__, "Could not end blob element");
 
     if (xmlTextWriterEndElement(xml.get_writer()) < 0)
         throw InternalErr(__FILE__, __LINE__, "Could not end Dataset element");
+#else
+#error Must define DAP2_DDX or DAP3_2_DDX
+#endif
 
     out << xml.get_doc();// << ends;// << endl;
 }
 
 /**
- * Print the DAP4 DMR object.
- * This method prints the DMR. If the dap version is not >= 4.0, it's an
+ * @brief Print the DAP4 DMR object using a DDS.
+ *
+ * This method prints the DMR from a DDS. If the dap version is not >= 4.0, it's an
  * error to call this method.
  *
  * @note Calling methods that print the DDS or DDX when get_dap_major()
@@ -1383,24 +1695,6 @@ DDS::print_dmr(ostream &out, bool constrained)
     // Print each variable
     for_each(var_begin(), var_end(), VariablePrintXMLWriter(xml, constrained));
 
-#if 0
-    // For DAP 3.2 and greater, use the new syntax and value. The 'blob' is
-    // the CID of the MIME part that holds the data. For DAP2 (which includes
-    // 3.0 and 3.1), the blob is an href. For DAP4, only write the CID if it's
-    // given.
-    if (get_dap_major() >= 4) {
-        if (!blob.empty()) {
-            if (xmlTextWriterStartElement(xml.get_writer(), (const xmlChar*) "blob") < 0)
-                throw InternalErr(__FILE__, __LINE__, "Could not write blob element");
-            string cid = "cid:" + blob;
-            if (xmlTextWriterWriteAttribute(xml.get_writer(), (const xmlChar*) "href", (const xmlChar*) cid.c_str()) < 0)
-                throw InternalErr(__FILE__, __LINE__, "Could not write attribute for d_name");
-            if (xmlTextWriterEndElement(xml.get_writer()) < 0)
-                throw InternalErr(__FILE__, __LINE__, "Could not end blob element");
-        }
-    }
-#endif
-
     if (xmlTextWriterEndElement(xml.get_writer()) < 0)
         throw InternalErr(__FILE__, __LINE__, "Could not end the top-level Group element");
 
@@ -1459,8 +1753,6 @@ DDS::check_semantics(bool all)
 
     @return True if the named variable was found, false otherwise.
 
-    @todo This should throw an exception on error!!!
-
     @todo These methods that use the btp_stack to keep track of the path from
     the top of a dataset to a particular variable can be rewritten to use the
     parent field instead.
@@ -1471,16 +1763,25 @@ DDS::check_semantics(bool all)
 bool
 DDS::mark(const string &n, bool state)
 {
+#if 0
     // TODO use auto_ptr
     BaseType::btp_stack *s = new BaseType::btp_stack;
+#endif
+
+    auto_ptr<BaseType::btp_stack> s(new BaseType::btp_stack);
 
     DBG2(cerr << "DDS::mark: Looking for " << n << endl);
 
-    BaseType *variable = var(n, s);
+    BaseType *variable = var(n, s.get());
     if (!variable) {
+        throw Error(malformed_expr, "Could not find variable " + n);
+#if 0
         DBG2(cerr << "Could not find variable " << n << endl);
+#if 0
         delete s; s = 0;
+#endif
         return false;
+#endif
     }
     variable->set_send_p(state);
 
@@ -1496,16 +1797,17 @@ DDS::mark(const string &n, bool state)
 
         DBG2(cerr << "DDS::mark: Set variable " << s->top()->d_name()
                 << " (a " << s->top()->type_name() << ")" << endl);
-        // FIXME get_parent() hosed?
-#if 1
+
         string parent_name = (s->top()->get_parent()) ? s->top()->get_parent()->name(): "none";
         string parent_type = (s->top()->get_parent()) ? s->top()->get_parent()->type_name(): "none";
         DBG2(cerr << "DDS::mark: Parent variable " << parent_name << " (a " << parent_type << ")" << endl);
-#endif
+
         s->pop();
     }
 
-    delete s ; s = 0;
+#if 0
+    delete s; s = 0;
+#endif
 
     return true;
 }
