@@ -62,7 +62,8 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         CE_EXPRSTYPE
 /* Substitute the variable and function names.  */
 #define yyparse         ce_exprparse
 #define yylex           ce_exprlex
@@ -99,10 +100,18 @@
 #ifndef YY_CE_EXPR_CE_EXPR_TAB_HH_INCLUDED
 # define YY_CE_EXPR_CE_EXPR_TAB_HH_INCLUDED
 /* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
+#ifndef CE_EXPRDEBUG
+# if defined YYDEBUG
 #if YYDEBUG
+#   define CE_EXPRDEBUG 1
+#  else
+#   define CE_EXPRDEBUG 0
+#  endif
+# else /* ! defined YYDEBUG */
+#  define CE_EXPRDEBUG 1
+# endif /* ! defined YYDEBUG */
+#endif  /* ! defined CE_EXPRDEBUG */
+#if CE_EXPRDEBUG
 extern int ce_exprdebug;
 #endif
 /* "%code requires" blocks.  */
@@ -160,6 +169,7 @@ using namespace libdap ;
 #define EVALUATOR(arg) (static_cast<ce_parser_arg*>(arg)->get_eval())
 #define DDS(arg) (static_cast<ce_parser_arg*>(arg)->get_dds())
 
+#define YYERROR_VERBOSE 0
 // #define YYPARSE_PARAM arg
 
 int ce_exprlex(void);		/* the scanner; see expr.lex */
@@ -202,12 +212,12 @@ template<class t, class T>
 rvalue *build_constant_array(vector<t> *values, DDS *dds);
 
 
-#line 206 "ce_expr.tab.cc" /* yacc.c:352  */
+#line 216 "ce_expr.tab.cc" /* yacc.c:352  */
 
 /* Token type.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-  enum yytokentype
+#ifndef CE_EXPRTOKENTYPE
+# define CE_EXPRTOKENTYPE
+  enum ce_exprtokentype
   {
     SCAN_STR = 258,
     SCAN_WORD = 259,
@@ -230,11 +240,11 @@ rvalue *build_constant_array(vector<t> *values, DDS *dds);
 #endif
 
 /* Value type.  */
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+#if ! defined CE_EXPRSTYPE && ! defined CE_EXPRSTYPE_IS_DECLARED
 
-union YYSTYPE
+union CE_EXPRSTYPE
 {
-#line 145 "ce_expr.yy" /* yacc.c:352  */
+#line 146 "ce_expr.yy" /* yacc.c:352  */
 
     bool boolean;
     int op;
@@ -267,16 +277,16 @@ union YYSTYPE
     libdap::rvalue *rval_ptr;
     libdap::rvalue_list *r_val_l_ptr;
 
-#line 271 "ce_expr.tab.cc" /* yacc.c:352  */
+#line 281 "ce_expr.tab.cc" /* yacc.c:352  */
 };
 
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
-# define YYSTYPE_IS_DECLARED 1
+typedef union CE_EXPRSTYPE CE_EXPRSTYPE;
+# define CE_EXPRSTYPE_IS_TRIVIAL 1
+# define CE_EXPRSTYPE_IS_DECLARED 1
 #endif
 
 
-extern YYSTYPE ce_exprlval;
+extern CE_EXPRSTYPE ce_exprlval;
 
 int ce_exprparse (ce_parser_arg *arg);
 
@@ -284,13 +294,13 @@ int ce_exprparse (ce_parser_arg *arg);
 
 
 /* Unqualified %code blocks.  */
-#line 232 "ce_expr.yy" /* yacc.c:355  */
+#line 233 "ce_expr.yy" /* yacc.c:355  */
 
 /* This global is used by the rule 'arg_length_hint' so that the hint can 
    be used during the paraent rule's parse. See fast_int32_arg_list. */
 unsigned long arg_length_hint_value = 0;
 
-#line 294 "ce_expr.tab.cc" /* yacc.c:355  */
+#line 304 "ce_expr.tab.cc" /* yacc.c:355  */
 
 #ifdef short
 # undef short
@@ -462,7 +472,7 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined CE_EXPRSTYPE_IS_TRIVIAL && CE_EXPRSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -576,23 +586,23 @@ static const yytype_uint8 yytranslate[] =
       15,    16,    17,    18,    19
 };
 
-#if YYDEBUG
+#if CE_EXPRDEBUG
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint16 yyrline[] =
 {
-       0,   241,   241,   247,   249,   249,   253,   259,   260,   266,
-     278,   282,   286,   310,   316,   322,   328,   334,   340,   346,
-     355,   366,   370,   377,   384,   388,   395,   402,   406,   413,
-     420,   424,   431,   438,   442,   449,   456,   460,   467,   474,
-     478,   485,   492,   514,   515,   521,   530,   541,   548,   562,
-     563,   573,   577,   583,   590,   599,   604,   609,   647,   671,
-     684,   690,   699,   705,   716,   721,   735,   739,   753,   762,
-     769,   781,   792,   807,   823,   824,   825,   826,   827,   828,
-     829
+       0,   242,   242,   248,   250,   250,   254,   260,   261,   267,
+     279,   283,   287,   311,   317,   323,   329,   335,   341,   347,
+     356,   367,   371,   378,   385,   389,   396,   403,   407,   414,
+     421,   425,   432,   439,   443,   450,   457,   461,   468,   475,
+     479,   486,   493,   515,   516,   522,   531,   542,   549,   563,
+     564,   574,   578,   584,   591,   600,   605,   610,   648,   672,
+     685,   691,   700,   706,   717,   722,   736,   740,   754,   763,
+     770,   782,   793,   808,   824,   825,   826,   827,   828,   829,
+     830
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || 0
+#if CE_EXPRDEBUG || YYERROR_VERBOSE || 0
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
@@ -829,7 +839,7 @@ static const yytype_uint8 yyr2[] =
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if CE_EXPRDEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -951,12 +961,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !CE_EXPRDEBUG */
 # define YYDPRINTF(Args)
 # define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !CE_EXPRDEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -1477,47 +1487,47 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 241 "ce_expr.yy" /* yacc.c:1652  */
+#line 242 "ce_expr.yy" /* yacc.c:1667  */
     {
              DBG(cerr << "Mark all variables" << endl);
 		     DDS(arg)->mark_all(true);
 		     (yyval.boolean) = true;
 		 }
-#line 1487 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1497 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 4:
-#line 249 "ce_expr.yy" /* yacc.c:1652  */
+#line 250 "ce_expr.yy" /* yacc.c:1667  */
     { DDS(arg)->mark_all(true); }
-#line 1493 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1503 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 5:
-#line 250 "ce_expr.yy" /* yacc.c:1652  */
+#line 251 "ce_expr.yy" /* yacc.c:1667  */
     { 
 		     (yyval.boolean) = (yyvsp[0].boolean);
 		 }
-#line 1501 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1511 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 6:
-#line 254 "ce_expr.yy" /* yacc.c:1652  */
+#line 255 "ce_expr.yy" /* yacc.c:1667  */
     {
 		     (yyval.boolean) = (yyvsp[-2].boolean) && (yyvsp[0].boolean);
 		 }
-#line 1509 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1519 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 8:
-#line 261 "ce_expr.yy" /* yacc.c:1652  */
+#line 262 "ce_expr.yy" /* yacc.c:1667  */
     {
 		     (yyval.boolean) = (yyvsp[-2].boolean) && (yyvsp[0].boolean);
 		 }
-#line 1517 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1527 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 9:
-#line 267 "ce_expr.yy" /* yacc.c:1652  */
+#line 268 "ce_expr.yy" /* yacc.c:1667  */
     {
 		     BaseType *var = DDS(arg)->var((yyvsp[0].id));
 		     if (var) {
@@ -1529,27 +1539,27 @@ yyreduce:
 			     no_such_ident(arg, (yyvsp[0].id), "identifier");
 		     }
 		}
-#line 1533 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1543 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 10:
-#line 279 "ce_expr.yy" /* yacc.c:1652  */
+#line 280 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    (yyval.boolean) = (yyvsp[0].boolean);
 		}
-#line 1541 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1551 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 11:
-#line 283 "ce_expr.yy" /* yacc.c:1652  */
+#line 284 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    (yyval.boolean) = (yyvsp[0].boolean);
 		}
-#line 1549 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1559 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 12:
-#line 287 "ce_expr.yy" /* yacc.c:1652  */
+#line 288 "ce_expr.yy" /* yacc.c:1667  */
     {
             Array *array = dynamic_cast<Array*>((yyvsp[0].rval_ptr)->bvalue(*DDS(arg)));
             if (array) { 
@@ -1567,67 +1577,67 @@ yyreduce:
                 return false;
             }
         }
-#line 1571 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1581 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 13:
-#line 311 "ce_expr.yy" /* yacc.c:1652  */
+#line 312 "ce_expr.yy" /* yacc.c:1667  */
     {
             (yyval.rval_ptr) = build_constant_array<dods_byte, Byte>((yyvsp[-1].byte_values), DDS(arg));
         }
-#line 1579 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1589 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 14:
-#line 317 "ce_expr.yy" /* yacc.c:1652  */
+#line 318 "ce_expr.yy" /* yacc.c:1667  */
     {
             (yyval.rval_ptr) = build_constant_array<dods_int16, Int16>((yyvsp[-1].int16_values), DDS(arg));
         }
-#line 1587 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1597 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 15:
-#line 323 "ce_expr.yy" /* yacc.c:1652  */
+#line 324 "ce_expr.yy" /* yacc.c:1667  */
     {
             (yyval.rval_ptr) = build_constant_array<dods_uint16, UInt16>((yyvsp[-1].uint16_values), DDS(arg));
         }
-#line 1595 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1605 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 16:
-#line 329 "ce_expr.yy" /* yacc.c:1652  */
+#line 330 "ce_expr.yy" /* yacc.c:1667  */
     {
             (yyval.rval_ptr) = build_constant_array<dods_int32, Int32>((yyvsp[-1].int32_values), DDS(arg));
         }
-#line 1603 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1613 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 17:
-#line 335 "ce_expr.yy" /* yacc.c:1652  */
+#line 336 "ce_expr.yy" /* yacc.c:1667  */
     {
             (yyval.rval_ptr) = build_constant_array<dods_uint32, UInt32>((yyvsp[-1].uint32_values), DDS(arg));
         }
-#line 1611 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1621 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 18:
-#line 341 "ce_expr.yy" /* yacc.c:1652  */
+#line 342 "ce_expr.yy" /* yacc.c:1667  */
     {
             (yyval.rval_ptr) = build_constant_array<dods_float32, Float32>((yyvsp[-1].float32_values), DDS(arg));
         }
-#line 1619 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1629 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 19:
-#line 347 "ce_expr.yy" /* yacc.c:1652  */
+#line 348 "ce_expr.yy" /* yacc.c:1667  */
     {
             (yyval.rval_ptr) = build_constant_array<dods_float64, Float64>((yyvsp[-1].float64_values), DDS(arg));
         }
-#line 1627 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1637 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 20:
-#line 356 "ce_expr.yy" /* yacc.c:1652  */
+#line 357 "ce_expr.yy" /* yacc.c:1667  */
     {
               if (!check_int32((yyvsp[0].id)))
                   throw Error(malformed_expr, "$<type>(hint, value, ...) special form expected hint to be an integer");
@@ -1635,179 +1645,179 @@ yyreduce:
               arg_length_hint_value = atoi((yyvsp[0].id));
               (yyval.boolean) = true;
           }
-#line 1639 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1649 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 21:
-#line 367 "ce_expr.yy" /* yacc.c:1652  */
+#line 368 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.byte_values) = make_fast_arg_list<byte_arg_list, dods_byte>(arg_length_hint_value, (yyvsp[0].byte_value));
           }
-#line 1647 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1657 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 22:
-#line 371 "ce_expr.yy" /* yacc.c:1652  */
+#line 372 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.byte_values) = make_fast_arg_list<byte_arg_list, dods_byte>((yyvsp[-2].byte_values), (yyvsp[0].byte_value));
           }
-#line 1655 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1665 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 23:
-#line 378 "ce_expr.yy" /* yacc.c:1652  */
+#line 379 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.byte_value) = strtol((yyvsp[0].id), 0, 0);
           }
-#line 1663 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1673 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 24:
-#line 385 "ce_expr.yy" /* yacc.c:1652  */
+#line 386 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.int16_values) = make_fast_arg_list<int16_arg_list, dods_int16>(arg_length_hint_value, (yyvsp[0].int16_value));
           }
-#line 1671 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1681 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 25:
-#line 389 "ce_expr.yy" /* yacc.c:1652  */
+#line 390 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.int16_values) = make_fast_arg_list<int16_arg_list, dods_int16>((yyvsp[-2].int16_values), (yyvsp[0].int16_value));
           }
-#line 1679 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1689 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 26:
-#line 396 "ce_expr.yy" /* yacc.c:1652  */
+#line 397 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.int16_value) = strtol((yyvsp[0].id), 0, 0);
           }
-#line 1687 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1697 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 27:
-#line 403 "ce_expr.yy" /* yacc.c:1652  */
+#line 404 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.uint16_values) = make_fast_arg_list<uint16_arg_list, dods_uint16>(arg_length_hint_value, (yyvsp[0].uint16_value));
           }
-#line 1695 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1705 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 28:
-#line 407 "ce_expr.yy" /* yacc.c:1652  */
+#line 408 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.uint16_values) = make_fast_arg_list<uint16_arg_list, dods_uint16>((yyvsp[-2].uint16_values), (yyvsp[0].uint16_value));
           }
-#line 1703 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1713 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 29:
-#line 414 "ce_expr.yy" /* yacc.c:1652  */
+#line 415 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.uint16_value) = strtoul((yyvsp[0].id), 0, 0);
           }
-#line 1711 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1721 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 30:
-#line 421 "ce_expr.yy" /* yacc.c:1652  */
+#line 422 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.int32_values) = make_fast_arg_list<int32_arg_list, dods_int32>(arg_length_hint_value, (yyvsp[0].int32_value));
           }
-#line 1719 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1729 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 31:
-#line 425 "ce_expr.yy" /* yacc.c:1652  */
+#line 426 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.int32_values) = make_fast_arg_list<int32_arg_list, dods_int32>((yyvsp[-2].int32_values), (yyvsp[0].int32_value));
           }
-#line 1727 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1737 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 32:
-#line 432 "ce_expr.yy" /* yacc.c:1652  */
+#line 433 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.int32_value) = strtol((yyvsp[0].id), 0, 0);
           }
-#line 1735 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1745 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 33:
-#line 439 "ce_expr.yy" /* yacc.c:1652  */
+#line 440 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.uint32_values) = make_fast_arg_list<uint32_arg_list, dods_uint32>(arg_length_hint_value, (yyvsp[0].uint32_value));
           }
-#line 1743 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1753 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 34:
-#line 443 "ce_expr.yy" /* yacc.c:1652  */
+#line 444 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.uint32_values) = make_fast_arg_list<uint32_arg_list, dods_uint32>((yyvsp[-2].uint32_values), (yyvsp[0].uint32_value));
           }
-#line 1751 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1761 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 35:
-#line 450 "ce_expr.yy" /* yacc.c:1652  */
+#line 451 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.uint32_value) = strtoul((yyvsp[0].id), 0, 0);
           }
-#line 1759 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1769 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 36:
-#line 457 "ce_expr.yy" /* yacc.c:1652  */
+#line 458 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.float32_values) = make_fast_arg_list<float32_arg_list, dods_float32>(arg_length_hint_value, (yyvsp[0].float32_value));
           }
-#line 1767 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1777 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 37:
-#line 461 "ce_expr.yy" /* yacc.c:1652  */
+#line 462 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.float32_values) = make_fast_arg_list<float32_arg_list, dods_float32>((yyvsp[-2].float32_values), (yyvsp[0].float32_value));
           }
-#line 1775 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1785 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 38:
-#line 468 "ce_expr.yy" /* yacc.c:1652  */
+#line 469 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.float32_value) = strtof((yyvsp[0].id), 0);
           }
-#line 1783 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1793 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 39:
-#line 475 "ce_expr.yy" /* yacc.c:1652  */
+#line 476 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.float64_values) = make_fast_arg_list<float64_arg_list, dods_float64>(arg_length_hint_value, (yyvsp[0].float64_value));
           }
-#line 1791 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1801 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 40:
-#line 479 "ce_expr.yy" /* yacc.c:1652  */
+#line 480 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.float64_values) = make_fast_arg_list<float64_arg_list, dods_float64>((yyvsp[-2].float64_values), (yyvsp[0].float64_value));
           }
-#line 1799 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1809 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 41:
-#line 486 "ce_expr.yy" /* yacc.c:1652  */
+#line 487 "ce_expr.yy" /* yacc.c:1667  */
     {
               (yyval.float64_value) = strtod((yyvsp[0].id), 0);
           }
-#line 1807 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1817 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 42:
-#line 493 "ce_expr.yy" /* yacc.c:1652  */
+#line 494 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    proj_func p_f = 0;
 		    btp_func f = 0;
@@ -1827,19 +1837,19 @@ yyreduce:
 			    no_such_func(arg, (yyvsp[-3].id));
 		    }
 		}
-#line 1831 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1841 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 44:
-#line 516 "ce_expr.yy" /* yacc.c:1652  */
+#line 517 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    (yyval.boolean) = (yyvsp[-2].boolean) && (yyvsp[0].boolean);
 		}
-#line 1839 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1849 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 45:
-#line 522 "ce_expr.yy" /* yacc.c:1652  */
+#line 523 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    if ((yyvsp[-4].rval_ptr)) {
 			EVALUATOR(arg)->append_clause((yyvsp[-3].op), (yyvsp[-4].rval_ptr), (yyvsp[-1].r_val_l_ptr));
@@ -1848,11 +1858,11 @@ yyreduce:
 		    else
 			(yyval.boolean) = false;
 		}
-#line 1852 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1862 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 46:
-#line 531 "ce_expr.yy" /* yacc.c:1652  */
+#line 532 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    if ((yyvsp[-2].rval_ptr)) {
 			rvalue_list *rv = new rvalue_list;
@@ -1863,19 +1873,19 @@ yyreduce:
 		    else
 			(yyval.boolean) = false;
 		}
-#line 1867 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1877 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 47:
-#line 542 "ce_expr.yy" /* yacc.c:1652  */
+#line 543 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    (yyval.boolean) = (yyvsp[0].boolean);
 		}
-#line 1875 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1885 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 48:
-#line 549 "ce_expr.yy" /* yacc.c:1652  */
+#line 550 "ce_expr.yy" /* yacc.c:1667  */
     {
 		   bool_func b_func = get_function((*EVALUATOR(arg)), (yyvsp[-3].id));
 		   if (!b_func) {
@@ -1886,11 +1896,11 @@ yyreduce:
 		       (yyval.boolean) = true;
 		   }
 	       }
-#line 1890 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1900 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 50:
-#line 564 "ce_expr.yy" /* yacc.c:1652  */
+#line 565 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    btp_func func = get_btp_function((*EVALUATOR(arg)), (yyvsp[-3].id));
 		    if (func) {
@@ -1900,65 +1910,65 @@ yyreduce:
 			    no_such_func(arg, (yyvsp[-3].id));
 		    }
 		}
-#line 1904 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1914 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 51:
-#line 574 "ce_expr.yy" /* yacc.c:1652  */
+#line 575 "ce_expr.yy" /* yacc.c:1667  */
     {
             (yyval.rval_ptr) = (yyvsp[0].rval_ptr);
         }
-#line 1912 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1922 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 52:
-#line 578 "ce_expr.yy" /* yacc.c:1652  */
+#line 579 "ce_expr.yy" /* yacc.c:1667  */
     {
             (yyval.rval_ptr) = (yyvsp[0].rval_ptr);
         }
-#line 1920 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1930 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 53:
-#line 584 "ce_expr.yy" /* yacc.c:1652  */
+#line 585 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    if ((yyvsp[0].rval_ptr))
 			    (yyval.r_val_l_ptr) = make_rvalue_list((yyvsp[0].rval_ptr));
 		    else
 			    (yyval.r_val_l_ptr) = 0;
 		}
-#line 1931 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1941 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 54:
-#line 591 "ce_expr.yy" /* yacc.c:1652  */
+#line 592 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    if ((yyvsp[-2].r_val_l_ptr) && (yyvsp[0].rval_ptr))
 			    (yyval.r_val_l_ptr) = append_rvalue_list((yyvsp[-2].r_val_l_ptr), (yyvsp[0].rval_ptr));
 		    else
 			    (yyval.r_val_l_ptr) = 0;
 		}
-#line 1942 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1952 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 55:
-#line 600 "ce_expr.yy" /* yacc.c:1652  */
+#line 601 "ce_expr.yy" /* yacc.c:1667  */
     {  
 		      (yyval.r_val_l_ptr) = (yyvsp[0].r_val_l_ptr);
 	      }
-#line 1950 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1960 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 56:
-#line 604 "ce_expr.yy" /* yacc.c:1652  */
+#line 605 "ce_expr.yy" /* yacc.c:1667  */
     { 
 		      (yyval.r_val_l_ptr) = 0; 
 	      }
-#line 1958 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 1968 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 57:
-#line 610 "ce_expr.yy" /* yacc.c:1652  */
+#line 611 "ce_expr.yy" /* yacc.c:1667  */
     { 
 		    BaseType *btp = DDS(arg)->var(www2id((yyvsp[0].id)));
 		    if (btp) {
@@ -1996,11 +2006,11 @@ yyreduce:
 			    (yyval.rval_ptr) = new rvalue(btp);
 		    }
 		}
-#line 2000 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2010 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 58:
-#line 648 "ce_expr.yy" /* yacc.c:1652  */
+#line 649 "ce_expr.yy" /* yacc.c:1667  */
     {
                     if ((yyvsp[0].val).type != dods_str_c || (yyvsp[0].val).v.s == 0 || (yyvsp[0].val).v.s->empty())
                         ce_exprerror(arg, "Malformed string", "");
@@ -2019,11 +2029,11 @@ yyreduce:
 		    // See ticket 2240. jhrg 7/30/14
 		    delete (yyvsp[0].val).v.s;
                 }
-#line 2023 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2033 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 59:
-#line 672 "ce_expr.yy" /* yacc.c:1652  */
+#line 673 "ce_expr.yy" /* yacc.c:1667  */
     {
                     if (!bracket_projection((*DDS(arg)), (yyvsp[-1].id), (yyvsp[0].int_ll_ptr)))
                       no_such_ident(arg, (yyvsp[-1].id), "array, grid or sequence");
@@ -2034,19 +2044,19 @@ yyreduce:
                     DDS(arg)->mark((yyvsp[-1].id), true);
                     (yyval.rval_ptr) = new rvalue(DDS(arg)->var((yyvsp[-1].id)));
                 }
-#line 2038 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2048 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 60:
-#line 685 "ce_expr.yy" /* yacc.c:1652  */
+#line 686 "ce_expr.yy" /* yacc.c:1667  */
     {
                     (yyval.boolean) = (*DDS(arg)).mark((yyvsp[0].id), true);
                 }
-#line 2046 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2056 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 61:
-#line 691 "ce_expr.yy" /* yacc.c:1652  */
+#line 692 "ce_expr.yy" /* yacc.c:1667  */
     {
                     //string name = www2id($1);
                     if (!bracket_projection((*DDS(arg)), (yyvsp[-1].id), (yyvsp[0].int_ll_ptr)))
@@ -2055,21 +2065,21 @@ yyreduce:
                     strncpy((yyval.id), (yyvsp[-1].id), ID_MAX-1);
                     (yyval.id)[ID_MAX-1] = '\0';
                 }
-#line 2059 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2069 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 62:
-#line 700 "ce_expr.yy" /* yacc.c:1652  */
+#line 701 "ce_expr.yy" /* yacc.c:1667  */
     {
                     string name = string((yyvsp[-1].id)) + string((yyvsp[0].id));
                     strncpy((yyval.id), name.c_str(), ID_MAX-1);
                     (yyval.id)[ID_MAX-1] = '\0';
                 }
-#line 2069 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2079 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 63:
-#line 706 "ce_expr.yy" /* yacc.c:1652  */
+#line 707 "ce_expr.yy" /* yacc.c:1667  */
     {
                     string name = string((yyvsp[-2].id)) + string((yyvsp[-1].id));
                     if (!bracket_projection((*DDS(arg)), name.c_str(), (yyvsp[0].int_ll_ptr)))
@@ -2078,20 +2088,20 @@ yyreduce:
                     strncpy((yyval.id), name.c_str(), ID_MAX-1);
                     (yyval.id)[ID_MAX-1] = '\0';
                 }
-#line 2082 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2092 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 64:
-#line 717 "ce_expr.yy" /* yacc.c:1652  */
+#line 718 "ce_expr.yy" /* yacc.c:1667  */
     { 
                     strncpy((yyval.id), www2id((yyvsp[0].id)).c_str(), ID_MAX-1);
                     (yyval.id)[ID_MAX-1] = '\0';
                 }
-#line 2091 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2101 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 65:
-#line 722 "ce_expr.yy" /* yacc.c:1652  */
+#line 723 "ce_expr.yy" /* yacc.c:1667  */
     {
                     if ((yyvsp[0].val).type != dods_str_c || (yyvsp[0].val).v.s == 0 || (yyvsp[0].val).v.s->empty())
                         ce_exprerror(arg, "Malformed string", "");
@@ -2103,27 +2113,27 @@ yyreduce:
 
                     (yyval.id)[ID_MAX-1] = '\0';
                 }
-#line 2107 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2117 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 66:
-#line 736 "ce_expr.yy" /* yacc.c:1652  */
+#line 737 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    (yyval.int_ll_ptr) = make_array_indices((yyvsp[0].int_l_ptr));
 		}
-#line 2115 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2125 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 67:
-#line 740 "ce_expr.yy" /* yacc.c:1652  */
+#line 741 "ce_expr.yy" /* yacc.c:1667  */
     {
 		    (yyval.int_ll_ptr) = append_array_index((yyvsp[-1].int_ll_ptr), (yyvsp[0].int_l_ptr));
 		}
-#line 2123 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2133 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 68:
-#line 754 "ce_expr.yy" /* yacc.c:1652  */
+#line 755 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!check_uint32((yyvsp[-1].id)))
         throw Error(malformed_expr, "The word `" + string((yyvsp[-1].id)) + "' is not a valid array index.");
@@ -2132,22 +2142,22 @@ yyreduce:
     i.v.i = atoi((yyvsp[-1].id));
     (yyval.int_l_ptr) = make_array_index(i);
 }
-#line 2136 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2146 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 69:
-#line 763 "ce_expr.yy" /* yacc.c:1652  */
+#line 764 "ce_expr.yy" /* yacc.c:1667  */
     {
     value i;
     i.type = dods_int32_c;
     i.v.i =-1;
     (yyval.int_l_ptr) = make_array_index(i);
 }
-#line 2147 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2157 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 70:
-#line 770 "ce_expr.yy" /* yacc.c:1652  */
+#line 771 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!check_uint32((yyvsp[-3].id)))
         throw Error(malformed_expr, "The word `" + string((yyvsp[-3].id)) + "' is not a valid array index.");
@@ -2159,11 +2169,11 @@ yyreduce:
     j.v.i = atoi((yyvsp[-1].id));
     (yyval.int_l_ptr) = make_array_index(i, j);
 }
-#line 2163 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2173 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 71:
-#line 782 "ce_expr.yy" /* yacc.c:1652  */
+#line 783 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!check_uint32((yyvsp[-3].id)))
         throw Error(malformed_expr, "The word `" + string((yyvsp[-3].id)) + "' is not a valid array index.");
@@ -2174,11 +2184,11 @@ yyreduce:
     j.v.i = -1;
     (yyval.int_l_ptr) = make_array_index(i, j);
 }
-#line 2178 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2188 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 72:
-#line 793 "ce_expr.yy" /* yacc.c:1652  */
+#line 794 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!check_uint32((yyvsp[-5].id)))
         throw Error(malformed_expr, "The word `" + string((yyvsp[-5].id)) + "' is not a valid array index.");
@@ -2193,11 +2203,11 @@ yyreduce:
     k.v.i = atoi((yyvsp[-1].id));
     (yyval.int_l_ptr) = make_array_index(i, j, k);
 }
-#line 2197 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2207 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
   case 73:
-#line 808 "ce_expr.yy" /* yacc.c:1652  */
+#line 809 "ce_expr.yy" /* yacc.c:1667  */
     {
     if (!check_uint32((yyvsp[-5].id)))
         throw Error(malformed_expr, "The word `" + string((yyvsp[-5].id)) + "' is not a valid array index.");
@@ -2211,11 +2221,11 @@ yyreduce:
     k.v.i = -1;
     (yyval.int_l_ptr) = make_array_index(i, j, k);
 }
-#line 2215 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2225 "ce_expr.tab.cc" /* yacc.c:1667  */
     break;
 
 
-#line 2219 "ce_expr.tab.cc" /* yacc.c:1652  */
+#line 2229 "ce_expr.tab.cc" /* yacc.c:1667  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2446,7 +2456,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 832 "ce_expr.yy" /* yacc.c:1918  */
+#line 833 "ce_expr.yy" /* yacc.c:1918  */
 
 
 // All these error reporting function now throw instances of Error. The expr
