@@ -96,10 +96,10 @@ chunked_inbuf::underflow()
 	// To read data from the chunked stream, first read the header
 	uint32_t header;
 	d_is.read((char *) &header, 4);
-#if !BYTE_ORDER_PREFIX
+#if !BYTE_ORDER_PREFIX && HEADER_IN_NETWORK_BYTE_ORDER
 	// When the endian nature of the server is encoded in the chunk header, the header is
 	// sent using network byte order
-	ntohl(header);
+	header = ntohl(header);
 #endif
 
 	// There are two 'EOF' cases: One where the END chunk is zero bytes and one where
@@ -218,8 +218,9 @@ chunked_inbuf::xsgetn(char* s, std::streamsize num)
         // Get a chunk header
         uint32_t header;
         d_is.read((char *) &header, 4);
-#if !BYTE_ORDER_PREFIX
-        ntohl(header);
+
+#if !BYTE_ORDER_PREFIX && HEADER_IN_NETWORK_BYTE_ORDER
+        header = ntohl(header);
 #endif
 
         // There are two EOF cases: One where the END chunk is zero bytes and one where
@@ -343,8 +344,9 @@ chunked_inbuf::read_next_chunk()
 	// To read data from the chunked stream, first read the header
 	uint32_t header;
 	d_is.read((char *) &header, 4);
-#if !BYTE_ORDER_PREFIX
-    ntohl(header);
+
+#if !BYTE_ORDER_PREFIX && HEADER_IN_NETWORK_BYTE_ORDER
+    header = ntohl(header);
 #endif
 
 	// There are two 'EOF' cases: One where the END chunk is zero bytes and one where
