@@ -41,7 +41,7 @@
 
 
 // Unqualified %code blocks.
-#line 77 "d4_function_parser.yy" // lalr1.cc:435
+#line 79 "d4_function_parser.yy" // lalr1.cc:435
 
     #include "BaseType.h"
     #include "DMR.h"
@@ -1031,7 +1031,7 @@ namespace libdap {
 
 
     // User initialization code.
-#line 69 "d4_function_parser.yy" // lalr1.cc:788
+#line 71 "d4_function_parser.yy" // lalr1.cc:791
 {
     // Initialize the initial location. This is printed when the parser builds
     // its own error messages - when the parse fails as opposed to when the 
@@ -1040,7 +1040,7 @@ namespace libdap {
     yyla.location.initialize (evaluator.expression());
 }
 
-#line 1044 "d4_function_parser.tab.cc" // lalr1.cc:788
+#line 1044 "d4_function_parser.tab.cc" // lalr1.cc:791
 
     /* Initialize the stack.  The initial state will be set in
        yynewstate, since the latter expects the semantical and the
@@ -1243,7 +1243,7 @@ namespace libdap {
           switch (yyn)
             {
   case 2:
-#line 156 "d4_function_parser.yy" // lalr1.cc:919
+#line 158 "d4_function_parser.yy" // lalr1.cc:919
     { 
     evaluator.set_result(yystack_[0].value.as < D4RValueList* > ()); 
 }
@@ -1251,7 +1251,7 @@ namespace libdap {
     break;
 
   case 3:
-#line 162 "d4_function_parser.yy" // lalr1.cc:919
+#line 164 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValueList* > () = new D4RValueList(yystack_[0].value.as < D4RValue* > ()); 
 }
@@ -1259,7 +1259,7 @@ namespace libdap {
     break;
 
   case 4:
-#line 166 "d4_function_parser.yy" // lalr1.cc:919
+#line 168 "d4_function_parser.yy" // lalr1.cc:919
     { 
     yystack_[2].value.as < D4RValueList* > ()->add_rvalue(yystack_[0].value.as < D4RValue* > ());
     yylhs.value.as < D4RValueList* > () = yystack_[2].value.as < D4RValueList* > (); 
@@ -1268,7 +1268,7 @@ namespace libdap {
     break;
 
   case 5:
-#line 173 "d4_function_parser.yy" // lalr1.cc:919
+#line 175 "d4_function_parser.yy" // lalr1.cc:919
     { 
     yylhs.value.as < D4RValue* > () = new D4RValue(yystack_[3].value.as < D4Function > (), yystack_[1].value.as < D4RValueList* > ()); // Build a D4RValue from a D4Function pointer and a D4RValueList 
 }
@@ -1276,7 +1276,7 @@ namespace libdap {
     break;
 
   case 6:
-#line 179 "d4_function_parser.yy" // lalr1.cc:919
+#line 181 "d4_function_parser.yy" // lalr1.cc:919
     { 
     D4Function f;
     if (!evaluator.sf_list()->find_function(yystack_[0].value.as < std::string > (), &f)) {
@@ -1290,7 +1290,7 @@ namespace libdap {
     break;
 
   case 7:
-#line 191 "d4_function_parser.yy" // lalr1.cc:919
+#line 193 "d4_function_parser.yy" // lalr1.cc:919
     { 
     yylhs.value.as < D4RValueList* > () = new D4RValueList(yystack_[0].value.as < D4RValue* > ()); // build a D4RValueList from the D4RValue
 }
@@ -1298,7 +1298,7 @@ namespace libdap {
     break;
 
   case 8:
-#line 195 "d4_function_parser.yy" // lalr1.cc:919
+#line 197 "d4_function_parser.yy" // lalr1.cc:919
     { 
     yystack_[2].value.as < D4RValueList* > ()->add_rvalue(yystack_[0].value.as < D4RValue* > ());
     yylhs.value.as < D4RValueList* > () = yystack_[2].value.as < D4RValueList* > (); // Append the D4RValue ($3) to the D4RValueList ($1), then return
@@ -1307,7 +1307,7 @@ namespace libdap {
     break;
 
   case 9:
-#line 202 "d4_function_parser.yy" // lalr1.cc:919
+#line 204 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = yystack_[0].value.as < D4RValue* > ();
 }
@@ -1315,7 +1315,7 @@ namespace libdap {
     break;
 
   case 10:
-#line 206 "d4_function_parser.yy" // lalr1.cc:919
+#line 208 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = yystack_[0].value.as < D4RValue* > ();
 }
@@ -1323,7 +1323,7 @@ namespace libdap {
     break;
 
   case 11:
-#line 210 "d4_function_parser.yy" // lalr1.cc:919
+#line 212 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < D4RValue* > () = yystack_[0].value.as < D4RValue* > ();
 }
@@ -1332,6 +1332,14 @@ namespace libdap {
 
   case 12:
 #line 216 "d4_function_parser.yy" // lalr1.cc:919
+    {
+    yylhs.value.as < D4RValue* > () = 0;
+}
+#line 1339 "d4_function_parser.tab.cc" // lalr1.cc:919
+    break;
+
+  case 13:
+#line 222 "d4_function_parser.yy" // lalr1.cc:919
     {
     D4RValue *rvalue = evaluator.build_rvalue(yystack_[0].value.as < std::string > ());
     if (!rvalue) {
@@ -1340,16 +1348,7 @@ namespace libdap {
     
     yylhs.value.as < D4RValue* > () = rvalue;
 }
-#line 1344 "d4_function_parser.tab.cc" // lalr1.cc:919
-    break;
-
-  case 13:
-#line 228 "d4_function_parser.yy" // lalr1.cc:919
-    {
-    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_byte>* > ()));
-    delete yystack_[1].value.as < std::vector<dods_byte>* > ();
-}
-#line 1353 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1352 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 14:
@@ -1358,94 +1357,95 @@ namespace libdap {
     yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_byte>* > ()));
     delete yystack_[1].value.as < std::vector<dods_byte>* > ();
 }
-#line 1362 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1361 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 15:
 #line 240 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int8>* > ()));
-    delete yystack_[1].value.as < std::vector<dods_int8>* > ();
+    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_byte>* > ()));
+    delete yystack_[1].value.as < std::vector<dods_byte>* > ();
 }
-#line 1371 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1370 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 16:
 #line 246 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_uint16>* > ()));
-    delete yystack_[1].value.as < std::vector<dods_uint16>* > ();
+    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int8>* > ()));
+    delete yystack_[1].value.as < std::vector<dods_int8>* > ();
 }
-#line 1380 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1379 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 17:
 #line 252 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int16>* > ()));
-    delete yystack_[1].value.as < std::vector<dods_int16>* > ();
+    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_uint16>* > ()));
+    delete yystack_[1].value.as < std::vector<dods_uint16>* > ();
 }
-#line 1389 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1388 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 18:
 #line 258 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_uint32>* > ()));
-    delete yystack_[1].value.as < std::vector<dods_uint32>* > ();
+    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int16>* > ()));
+    delete yystack_[1].value.as < std::vector<dods_int16>* > ();
 }
-#line 1398 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1397 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 19:
 #line 264 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int32>* > ()));
-    delete yystack_[1].value.as < std::vector<dods_int32>* > ();
+    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_uint32>* > ()));
+    delete yystack_[1].value.as < std::vector<dods_uint32>* > ();
 }
-#line 1407 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1406 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 20:
 #line 270 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_uint64>* > ()));
-    delete yystack_[1].value.as < std::vector<dods_uint64>* > ();
+    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int32>* > ()));
+    delete yystack_[1].value.as < std::vector<dods_int32>* > ();
 }
-#line 1416 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1415 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 21:
 #line 276 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int64>* > ()));
-    delete yystack_[1].value.as < std::vector<dods_int64>* > ();
+    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_uint64>* > ()));
+    delete yystack_[1].value.as < std::vector<dods_uint64>* > ();
 }
-#line 1425 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1424 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 22:
 #line 282 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_float32>* > ()));
-    delete yystack_[1].value.as < std::vector<dods_float32>* > ();
+    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_int64>* > ()));
+    delete yystack_[1].value.as < std::vector<dods_int64>* > ();
 }
-#line 1434 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1433 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 23:
 #line 288 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_float64>* > ()));
-    delete yystack_[1].value.as < std::vector<dods_float64>* > ();
+    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_float32>* > ()));
+    delete yystack_[1].value.as < std::vector<dods_float32>* > ();
 }
-#line 1443 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1442 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 24:
-#line 300 "d4_function_parser.yy" // lalr1.cc:919
+#line 294 "d4_function_parser.yy" // lalr1.cc:919
     {
-    evaluator.set_arg_length_hint(get_uint64(yystack_[0].value.as < std::string > ().c_str()));
+    yylhs.value.as < D4RValue* > () = new D4RValue(*(yystack_[1].value.as < std::vector<dods_float64>* > ()));
+    delete yystack_[1].value.as < std::vector<dods_float64>* > ();
 }
 #line 1451 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
@@ -1453,255 +1453,263 @@ namespace libdap {
   case 25:
 #line 306 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < std::vector<dods_byte>* > () = evaluator.init_arg_list(dods_byte(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
+    evaluator.set_arg_length_hint(get_uint64(yystack_[0].value.as < std::string > ().c_str()));
 }
 #line 1459 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 26:
-#line 310 "d4_function_parser.yy" // lalr1.cc:919
+#line 312 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yystack_[2].value.as < std::vector<dods_byte>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
-    yylhs.value.as < std::vector<dods_byte>* > () = yystack_[2].value.as < std::vector<dods_byte>* > ();
+    yylhs.value.as < std::vector<dods_byte>* > () = evaluator.init_arg_list(dods_byte(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1468 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1467 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 27:
-#line 317 "d4_function_parser.yy" // lalr1.cc:919
+#line 316 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < std::vector<dods_int8>* > () = evaluator.init_arg_list(dods_int8(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
+    yystack_[2].value.as < std::vector<dods_byte>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
+    yylhs.value.as < std::vector<dods_byte>* > () = yystack_[2].value.as < std::vector<dods_byte>* > ();
 }
 #line 1476 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 28:
-#line 321 "d4_function_parser.yy" // lalr1.cc:919
+#line 323 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yystack_[2].value.as < std::vector<dods_int8>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
-    yylhs.value.as < std::vector<dods_int8>* > () = yystack_[2].value.as < std::vector<dods_int8>* > ();
+    yylhs.value.as < std::vector<dods_int8>* > () = evaluator.init_arg_list(dods_int8(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1485 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1484 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 29:
-#line 328 "d4_function_parser.yy" // lalr1.cc:919
+#line 327 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < std::vector<dods_uint16>* > () = evaluator.init_arg_list(dods_uint16(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
+    yystack_[2].value.as < std::vector<dods_int8>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
+    yylhs.value.as < std::vector<dods_int8>* > () = yystack_[2].value.as < std::vector<dods_int8>* > ();
 }
 #line 1493 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 30:
-#line 332 "d4_function_parser.yy" // lalr1.cc:919
+#line 334 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yystack_[2].value.as < std::vector<dods_uint16>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
-    yylhs.value.as < std::vector<dods_uint16>* > () = yystack_[2].value.as < std::vector<dods_uint16>* > ();
+    yylhs.value.as < std::vector<dods_uint16>* > () = evaluator.init_arg_list(dods_uint16(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1502 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1501 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 31:
-#line 339 "d4_function_parser.yy" // lalr1.cc:919
+#line 338 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < std::vector<dods_int16>* > () = evaluator.init_arg_list(dods_int16(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
+    yystack_[2].value.as < std::vector<dods_uint16>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
+    yylhs.value.as < std::vector<dods_uint16>* > () = yystack_[2].value.as < std::vector<dods_uint16>* > ();
 }
 #line 1510 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 32:
-#line 343 "d4_function_parser.yy" // lalr1.cc:919
+#line 345 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yystack_[2].value.as < std::vector<dods_int16>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
-    yylhs.value.as < std::vector<dods_int16>* > () = yystack_[2].value.as < std::vector<dods_int16>* > ();
+    yylhs.value.as < std::vector<dods_int16>* > () = evaluator.init_arg_list(dods_int16(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1519 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1518 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 33:
-#line 350 "d4_function_parser.yy" // lalr1.cc:919
+#line 349 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < std::vector<dods_uint32>* > () = evaluator.init_arg_list(dods_uint32(strtoul(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
+    yystack_[2].value.as < std::vector<dods_int16>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
+    yylhs.value.as < std::vector<dods_int16>* > () = yystack_[2].value.as < std::vector<dods_int16>* > ();
 }
 #line 1527 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 34:
-#line 354 "d4_function_parser.yy" // lalr1.cc:919
+#line 356 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yystack_[2].value.as < std::vector<dods_uint32>* > ()->push_back(strtoul(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
-    yylhs.value.as < std::vector<dods_uint32>* > () = yystack_[2].value.as < std::vector<dods_uint32>* > ();
+    yylhs.value.as < std::vector<dods_uint32>* > () = evaluator.init_arg_list(dods_uint32(strtoul(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1536 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1535 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 35:
 #line 360 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < std::vector<dods_int32>* > () = evaluator.init_arg_list(dods_int32(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
+    yystack_[2].value.as < std::vector<dods_uint32>* > ()->push_back(strtoul(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
+    yylhs.value.as < std::vector<dods_uint32>* > () = yystack_[2].value.as < std::vector<dods_uint32>* > ();
 }
 #line 1544 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 36:
-#line 364 "d4_function_parser.yy" // lalr1.cc:919
+#line 366 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yystack_[2].value.as < std::vector<dods_int32>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
-    yylhs.value.as < std::vector<dods_int32>* > () = yystack_[2].value.as < std::vector<dods_int32>* > ();
+    yylhs.value.as < std::vector<dods_int32>* > () = evaluator.init_arg_list(dods_int32(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1553 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1552 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 37:
-#line 371 "d4_function_parser.yy" // lalr1.cc:919
+#line 370 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < std::vector<dods_uint64>* > () = evaluator.init_arg_list(dods_uint64(strtoull(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
+    yystack_[2].value.as < std::vector<dods_int32>* > ()->push_back(strtol(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
+    yylhs.value.as < std::vector<dods_int32>* > () = yystack_[2].value.as < std::vector<dods_int32>* > ();
 }
 #line 1561 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 38:
-#line 375 "d4_function_parser.yy" // lalr1.cc:919
+#line 377 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yystack_[2].value.as < std::vector<dods_uint64>* > ()->push_back(strtoull(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
-    yylhs.value.as < std::vector<dods_uint64>* > () = yystack_[2].value.as < std::vector<dods_uint64>* > ();
+    yylhs.value.as < std::vector<dods_uint64>* > () = evaluator.init_arg_list(dods_uint64(strtoull(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1570 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1569 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 39:
-#line 382 "d4_function_parser.yy" // lalr1.cc:919
+#line 381 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < std::vector<dods_int64>* > () = evaluator.init_arg_list(dods_int64(strtoll(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
+    yystack_[2].value.as < std::vector<dods_uint64>* > ()->push_back(strtoull(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
+    yylhs.value.as < std::vector<dods_uint64>* > () = yystack_[2].value.as < std::vector<dods_uint64>* > ();
 }
 #line 1578 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 40:
-#line 386 "d4_function_parser.yy" // lalr1.cc:919
+#line 388 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yystack_[2].value.as < std::vector<dods_int64>* > ()->push_back(strtoll(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
-    yylhs.value.as < std::vector<dods_int64>* > () = yystack_[2].value.as < std::vector<dods_int64>* > ();
+    yylhs.value.as < std::vector<dods_int64>* > () = evaluator.init_arg_list(dods_int64(strtoll(yystack_[0].value.as < std::string > ().c_str(), 0, 0)));
 }
-#line 1587 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1586 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 41:
-#line 396 "d4_function_parser.yy" // lalr1.cc:919
+#line 392 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < std::vector<dods_float32>* > () = evaluator.init_arg_list(dods_float32(strtof(yystack_[0].value.as < std::string > ().c_str(), 0)));
+    yystack_[2].value.as < std::vector<dods_int64>* > ()->push_back(strtoll(yystack_[0].value.as < std::string > ().c_str(), 0, 0));
+    yylhs.value.as < std::vector<dods_int64>* > () = yystack_[2].value.as < std::vector<dods_int64>* > ();
 }
 #line 1595 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 42:
-#line 400 "d4_function_parser.yy" // lalr1.cc:919
+#line 402 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yystack_[2].value.as < std::vector<dods_float32>* > ()->push_back(strtof(yystack_[0].value.as < std::string > ().c_str(), 0));
-    yylhs.value.as < std::vector<dods_float32>* > () = yystack_[2].value.as < std::vector<dods_float32>* > ();
+    yylhs.value.as < std::vector<dods_float32>* > () = evaluator.init_arg_list(dods_float32(strtof(yystack_[0].value.as < std::string > ().c_str(), 0)));
 }
-#line 1604 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1603 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 43:
-#line 407 "d4_function_parser.yy" // lalr1.cc:919
+#line 406 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < std::vector<dods_float64>* > () = evaluator.init_arg_list(dods_float64(strtod(yystack_[0].value.as < std::string > ().c_str(), 0)));
+    yystack_[2].value.as < std::vector<dods_float32>* > ()->push_back(strtof(yystack_[0].value.as < std::string > ().c_str(), 0));
+    yylhs.value.as < std::vector<dods_float32>* > () = yystack_[2].value.as < std::vector<dods_float32>* > ();
 }
 #line 1612 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 44:
-#line 411 "d4_function_parser.yy" // lalr1.cc:919
+#line 413 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yystack_[2].value.as < std::vector<dods_float64>* > ()->push_back(strtod(yystack_[0].value.as < std::string > ().c_str(), 0));
-    yylhs.value.as < std::vector<dods_float64>* > () = yystack_[2].value.as < std::vector<dods_float64>* > ();
+    yylhs.value.as < std::vector<dods_float64>* > () = evaluator.init_arg_list(dods_float64(strtod(yystack_[0].value.as < std::string > ().c_str(), 0)));
 }
-#line 1621 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1620 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 45:
-#line 418 "d4_function_parser.yy" // lalr1.cc:919
+#line 417 "d4_function_parser.yy" // lalr1.cc:919
     {
-    yylhs.value.as < std::string > () = yystack_[0].value.as < std::string > ();
+    yystack_[2].value.as < std::vector<dods_float64>* > ()->push_back(strtod(yystack_[0].value.as < std::string > ().c_str(), 0));
+    yylhs.value.as < std::vector<dods_float64>* > () = yystack_[2].value.as < std::vector<dods_float64>* > ();
 }
 #line 1629 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 46:
-#line 422 "d4_function_parser.yy" // lalr1.cc:919
+#line 424 "d4_function_parser.yy" // lalr1.cc:919
+    {
+    yylhs.value.as < std::string > () = yystack_[0].value.as < std::string > ();
+}
+#line 1637 "d4_function_parser.tab.cc" // lalr1.cc:919
+    break;
+
+  case 47:
+#line 428 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > ().append("/");
     yylhs.value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
 }
-#line 1638 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1646 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
-  case 47:
-#line 427 "d4_function_parser.yy" // lalr1.cc:919
+  case 48:
+#line 433 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::string > ().append("/");
     yystack_[2].value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
     yylhs.value.as < std::string > () = yystack_[2].value.as < std::string > ();
 }
-#line 1648 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1656 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
-  case 48:
-#line 435 "d4_function_parser.yy" // lalr1.cc:919
+  case 49:
+#line 441 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > ().append("/");
     yylhs.value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
 }
-#line 1657 "d4_function_parser.tab.cc" // lalr1.cc:919
+#line 1665 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
-  case 49:
-#line 440 "d4_function_parser.yy" // lalr1.cc:919
+  case 50:
+#line 446 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::string > ().append(".");
     yystack_[2].value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
     yylhs.value.as < std::string > () = yystack_[2].value.as < std::string > ();
 }
-#line 1667 "d4_function_parser.tab.cc" // lalr1.cc:919
-    break;
-
-  case 50:
-#line 448 "d4_function_parser.yy" // lalr1.cc:919
-    {
-    yylhs.value.as < std::string > () = yystack_[0].value.as < std::string > ();
-}
 #line 1675 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 51:
-#line 452 "d4_function_parser.yy" // lalr1.cc:919
+#line 454 "d4_function_parser.yy" // lalr1.cc:919
+    {
+    yylhs.value.as < std::string > () = yystack_[0].value.as < std::string > ();
+}
+#line 1683 "d4_function_parser.tab.cc" // lalr1.cc:919
+    break;
+
+  case 52:
+#line 458 "d4_function_parser.yy" // lalr1.cc:919
     {
     yystack_[2].value.as < std::string > ().append(".");
     yystack_[2].value.as < std::string > ().append(yystack_[0].value.as < std::string > ());
     yylhs.value.as < std::string > () = yystack_[2].value.as < std::string > ();
 }
-#line 1685 "d4_function_parser.tab.cc" // lalr1.cc:919
-    break;
-
-  case 52:
-#line 463 "d4_function_parser.yy" // lalr1.cc:919
-    {
-    yylhs.value.as < std::string > ()=yystack_[0].value.as < std::string > ();
-}
 #line 1693 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
   case 53:
-#line 467 "d4_function_parser.yy" // lalr1.cc:919
+#line 469 "d4_function_parser.yy" // lalr1.cc:919
     {
     yylhs.value.as < std::string > ()=yystack_[0].value.as < std::string > ();
 }
 #line 1701 "d4_function_parser.tab.cc" // lalr1.cc:919
     break;
 
+  case 54:
+#line 473 "d4_function_parser.yy" // lalr1.cc:919
+    {
+    yylhs.value.as < std::string > ()=yystack_[0].value.as < std::string > ();
+}
+#line 1709 "d4_function_parser.tab.cc" // lalr1.cc:919
+    break;
 
-#line 1705 "d4_function_parser.tab.cc" // lalr1.cc:919
+
+#line 1713 "d4_function_parser.tab.cc" // lalr1.cc:919
             default:
               break;
             }
@@ -1973,7 +1981,7 @@ namespace libdap {
 
   const signed char D4FunctionParser::yypact_ninf_ = -20;
 
-  const signed char D4FunctionParser::yytable_ninf_ = -50;
+  const signed char D4FunctionParser::yytable_ninf_ = -51;
 
   const signed char
   D4FunctionParser::yypact_[] =
@@ -1996,19 +2004,19 @@ namespace libdap {
   const unsigned char
   D4FunctionParser::yydefact_[] =
   {
-       0,     6,     0,     2,     3,     0,     1,     0,     0,     4,
-      52,    53,     0,     0,     0,     0,     0,     0,     0,     0,
-       0,     0,     0,     0,     9,     0,     7,    10,    11,    12,
-       0,    45,    50,    52,    46,    50,     0,     0,     0,     0,
-       0,     0,     0,     0,     0,     0,     0,     5,     0,     0,
-       0,    24,     0,     0,     0,     0,     0,     0,     0,     0,
-       0,     0,     0,     8,    47,    50,    51,     0,     0,     0,
-       0,     0,     0,     0,     0,     0,     0,     0,    25,     0,
-       0,    27,     0,    29,     0,    31,     0,    33,     0,    35,
-       0,    37,     0,    39,     0,     0,    41,     0,    43,    13,
-       0,    14,    15,     0,    16,     0,    17,     0,    18,     0,
-      19,     0,    20,     0,    21,     0,    22,     0,    23,     0,
-      26,    28,    30,    32,    34,    36,    38,    40,    42,    44
+       0,     6,     0,     2,     3,     0,     1,     0,    12,     4,
+      53,    54,     0,     0,     0,     0,     0,     0,     0,     0,
+       0,     0,     0,     0,     9,     0,     7,    10,    11,    13,
+       0,    46,    51,    53,    47,    51,     0,     0,     0,     0,
+       0,     0,     0,     0,     0,     0,     0,     5,    12,     0,
+       0,    25,     0,     0,     0,     0,     0,     0,     0,     0,
+       0,     0,     0,     8,    48,    51,    52,     0,     0,     0,
+       0,     0,     0,     0,     0,     0,     0,     0,    26,     0,
+       0,    28,     0,    30,     0,    32,     0,    34,     0,    36,
+       0,    38,     0,    40,     0,     0,    42,     0,    44,    14,
+       0,    15,    16,     0,    17,     0,    18,     0,    19,     0,
+      20,     0,    21,     0,    22,     0,    23,     0,    24,     0,
+      27,    29,    31,    33,    35,    37,    39,    41,    43,    45
   };
 
   const signed char
@@ -2038,8 +2046,8 @@ namespace libdap {
      109,   110,   111,   112,   113,   114,   115,   116,   117,   118,
      119,    -6,    36,    37,    96,    98,    38,    39,    40,    41,
       42,    43,    44,    45,    46,    51,    67,    78,    49,    68,
-      50,   -48,    69,    70,    71,    72,    73,    74,    75,    76,
-      77,    81,    83,    85,    87,   -49,    89,    91,    93,   120,
+      50,   -49,    69,    70,    71,    72,    73,    74,    75,    76,
+      77,    81,    83,    85,    87,   -50,    89,    91,    93,   120,
      121,   122,   123,   124,   125,   128,   126,   129,   127,    80,
        0,     0,     0,     0,     0,     0,     0,    63
   };
@@ -2083,22 +2091,22 @@ namespace libdap {
   D4FunctionParser::yyr1_[] =
   {
        0,    40,    41,    42,    42,    43,    44,    45,    45,    46,
-      46,    46,    47,    48,    48,    48,    48,    48,    48,    48,
-      48,    48,    48,    48,    49,    50,    50,    51,    51,    52,
-      52,    53,    53,    54,    54,    55,    55,    56,    56,    57,
-      57,    58,    58,    59,    59,    60,    60,    60,    61,    61,
-      62,    62,    63,    63
+      46,    46,    46,    47,    48,    48,    48,    48,    48,    48,
+      48,    48,    48,    48,    48,    49,    50,    50,    51,    51,
+      52,    52,    53,    53,    54,    54,    55,    55,    56,    56,
+      57,    57,    58,    58,    59,    59,    60,    60,    60,    61,
+      61,    62,    62,    63,    63
   };
 
   const unsigned char
   D4FunctionParser::yyr2_[] =
   {
        0,     2,     1,     1,     3,     4,     1,     1,     3,     1,
-       1,     1,     1,     6,     6,     6,     6,     6,     6,     6,
-       6,     6,     6,     6,     1,     1,     3,     1,     3,     1,
-       3,     1,     3,     1,     3,     1,     3,     1,     3,     1,
-       3,     1,     3,     1,     3,     1,     2,     3,     2,     3,
-       1,     3,     1,     1
+       1,     1,     0,     1,     6,     6,     6,     6,     6,     6,
+       6,     6,     6,     6,     6,     1,     1,     3,     1,     3,
+       1,     3,     1,     3,     1,     3,     1,     3,     1,     3,
+       1,     3,     1,     3,     1,     3,     1,     2,     3,     2,
+       3,     1,     3,     1,     1
   };
 
 
@@ -2132,12 +2140,12 @@ namespace libdap {
   const unsigned short
   D4FunctionParser::yyrline_[] =
   {
-       0,   155,   155,   161,   165,   172,   178,   190,   194,   201,
-     205,   209,   215,   227,   233,   239,   245,   251,   257,   263,
-     269,   275,   281,   287,   299,   305,   309,   316,   320,   327,
-     331,   338,   342,   349,   353,   359,   363,   370,   374,   381,
-     385,   395,   399,   406,   410,   417,   421,   426,   434,   439,
-     447,   451,   462,   466
+       0,   157,   157,   163,   167,   174,   180,   192,   196,   203,
+     207,   211,   216,   221,   233,   239,   245,   251,   257,   263,
+     269,   275,   281,   287,   293,   305,   311,   315,   322,   326,
+     333,   337,   344,   348,   355,   359,   365,   369,   376,   380,
+     387,   391,   401,   405,   412,   416,   423,   427,   432,   440,
+     445,   453,   457,   468,   472
   };
 
   // Print the state stack on the debug stream.
@@ -2222,8 +2230,8 @@ namespace libdap {
 
 #line 34 "d4_function_parser.yy" // lalr1.cc:1242
 } // libdap
-#line 2226 "d4_function_parser.tab.cc" // lalr1.cc:1242
-#line 472 "d4_function_parser.yy" // lalr1.cc:1243
+#line 2234 "d4_function_parser.tab.cc" // lalr1.cc:1242
+#line 478 "d4_function_parser.yy" // lalr1.cc:1243
 
 
 // Forward the error to the driver for handling. The location parameter
