@@ -56,57 +56,66 @@ private:
     D4Dimensions *d;
 
 public:
-    D4DimensionsTest() : xml(0), d(0) {
+    D4DimensionsTest() :
+        xml(0), d(0)
+    {
     }
 
-    ~D4DimensionsTest() {
+    ~D4DimensionsTest()
+    {
     }
 
-    void setUp() {
+    void setUp()
+    {
         d = new D4Dimensions;
         xml = new XMLWriter;
     }
 
-    void tearDown() {
+    void tearDown()
+    {
         delete xml;
         delete d;
     }
 
     // An empty D4Dimensions object prints nothing; the XMLWriter class adds
     // a xml doc preface.
-    void test_print_empty() {
+    void test_print_empty()
+    {
         d->print_dap4(*xml);
         string doc = xml->get_doc();
-        string baseline = readTestBaseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_empty.xml");
+        string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_empty.xml");
         DBG(cerr << "test_print_empty: doc: " << doc << endl);
         DBG(cerr << "test_print_empty: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_1() {
+    void test_print_1()
+    {
         d->add_dim_nocopy(new D4Dimension("first", 10));
 
         d->print_dap4(*xml);
         string doc = xml->get_doc();
-        string baseline = readTestBaseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_1.xml");
+        string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_1.xml");
         DBG(cerr << "test_print_1: doc: " << doc << endl);
         DBG(cerr << "test_print_1: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_2() {
+    void test_print_2()
+    {
         d->add_dim_nocopy(new D4Dimension("first", 10));
         d->add_dim_nocopy(new D4Dimension("second", 100));
 
         d->print_dap4(*xml);
         string doc = xml->get_doc();
-        string baseline = readTestBaseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_2.xml");
+        string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_2.xml");
         DBG(cerr << "test_print_2: doc: " << doc << endl);
         DBG(cerr << "test_print_2: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_error() {
+    void test_error()
+    {
         D4Dimension *d3, *d2;
         try {
             d2 = new D4Dimension();
@@ -116,16 +125,19 @@ public:
             d3 = new D4Dimension();
             d3->set_name("error");
             d3->set_size("20.0");
-            delete d3; delete d2;
+            delete d3;
+            delete d2;
             CPPUNIT_FAIL("Should throw an Error");
         }
-        catch(...) {
-            delete d3; delete d2;
+        catch (...) {
+            delete d3;
+            delete d2;
             throw;
         }
     }
 
-    void test_error_2() {
+    void test_error_2()
+    {
         D4Dimension *d3;
         try {
             d3 = new D4Dimension();
@@ -134,7 +146,7 @@ public:
             delete d3;
             CPPUNIT_FAIL("Should throw an Error");
         }
-        catch(...) {
+        catch (...) {
             delete d3;
             throw;
         }
@@ -147,13 +159,14 @@ public:
 
         d->print_dap4(*xml);
         string doc = xml->get_doc();
-        string baseline = readTestBaseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_3.xml");
+        string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_3.xml");
         DBG(cerr << "test_print_varying: doc: " << doc << endl);
         DBG(cerr << "test_print_varying: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 #endif
-    void test_print_insert_dim() {
+    void test_print_insert_dim()
+    {
         d->add_dim_nocopy(new D4Dimension("first", 10));
         d->add_dim_nocopy(new D4Dimension("second", 100));
         d->add_dim_nocopy(new D4Dimension("third", 1000));
@@ -164,13 +177,14 @@ public:
 
         d->print_dap4(*xml);
         string doc = xml->get_doc();
-        string baseline = readTestBaseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_4.xml");
+        string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_4.xml");
         DBG(cerr << "test_print_insert_dim: doc: " << doc << endl);
         DBG(cerr << "test_print_insert_dim: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_assignment() {
+    void test_print_assignment()
+    {
         d->add_dim_nocopy(new D4Dimension("first", 10));
         d->add_dim_nocopy(new D4Dimension("second", 100));
         d->add_dim_nocopy(new D4Dimension("third", 1000));
@@ -179,13 +193,14 @@ public:
 
         lhs.print_dap4(*xml);
         string doc = xml->get_doc();
-        string baseline = readTestBaseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_3.xml");
+        string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_3.xml");
         DBG(cerr << "test_print_assignment: doc: " << doc << endl);
         DBG(cerr << "test_print_assignment: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    void test_print_copy_ctor() {
+    void test_print_copy_ctor()
+    {
         d->add_dim_nocopy(new D4Dimension("first", 10));
         d->add_dim_nocopy(new D4Dimension("second", 100));
         d->add_dim_nocopy(new D4Dimension("third", 1000));
@@ -194,38 +209,36 @@ public:
 
         lhs.print_dap4(*xml);
         string doc = xml->get_doc();
-        string baseline = readTestBaseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_3.xml");
+        string baseline = read_test_baseline(string(TEST_SRC_DIR) + "/D4-xml/D4Dimensions_3.xml");
         DBG(cerr << "test_print_copy_ctor: doc: " << doc << endl);
         DBG(cerr << "test_print_copy_ctor: baseline: " << baseline << endl);
         CPPUNIT_ASSERT(doc == baseline);
     }
 
-    CPPUNIT_TEST_SUITE( D4DimensionsTest );
+    CPPUNIT_TEST_SUITE (D4DimensionsTest);
 
-        CPPUNIT_TEST(test_print_empty);
-        CPPUNIT_TEST(test_print_1);
-        CPPUNIT_TEST(test_print_2);
+    CPPUNIT_TEST (test_print_empty);
+    CPPUNIT_TEST (test_print_1);
+    CPPUNIT_TEST (test_print_2);
 
-        CPPUNIT_TEST_EXCEPTION( test_error, Error );
-        //CPPUNIT_TEST( test_error );
-        CPPUNIT_TEST_EXCEPTION( test_error_2, Error );
+    CPPUNIT_TEST_EXCEPTION( test_error, Error );
+    //CPPUNIT_TEST( test_error );
+    CPPUNIT_TEST_EXCEPTION( test_error_2, Error );
 #ifdef VARYING
-        CPPUNIT_TEST(test_print_varying);
+    CPPUNIT_TEST(test_print_varying);
 #endif
-        CPPUNIT_TEST(test_print_insert_dim);
-        CPPUNIT_TEST(test_print_assignment);
-        CPPUNIT_TEST(test_print_copy_ctor);
+    CPPUNIT_TEST (test_print_insert_dim);
+    CPPUNIT_TEST (test_print_assignment);
+    CPPUNIT_TEST (test_print_copy_ctor);
 
     CPPUNIT_TEST_SUITE_END();
 };
 
-CPPUNIT_TEST_SUITE_REGISTRATION(D4DimensionsTest);
+CPPUNIT_TEST_SUITE_REGISTRATION (D4DimensionsTest);
 
-int main(int argc, char*argv[]) {
-    CppUnit::TextTestRunner runner;
-    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
-
-    GetOpt getopt(argc, argv, "d");
+int main(int argc, char*argv[])
+{
+    GetOpt getopt(argc, argv, "dh");
     int option_char;
 
     while ((option_char = getopt()) != -1)
@@ -233,10 +246,22 @@ int main(int argc, char*argv[]) {
         case 'd':
             debug = 1;  // debug is a static global
             break;
+        case 'h': {     // help - show test names
+            cerr << "Usage: D4DimensionsTest has the following tests:" << endl;
+            const std::vector<Test*> &tests = D4DimensionsTest::suite()->getTests();
+            unsigned int prefix_len = D4DimensionsTest::suite()->getName().append("::").length();
+            for (std::vector<Test*>::const_iterator i = tests.begin(), e = tests.end(); i != e; ++i) {
+                cerr << (*i)->getName().replace(0, prefix_len, "") << endl;
+            }
+            break;
+        }
         default:
             break;
         }
 
+    CppUnit::TextTestRunner runner;
+    runner.addTest(CppUnit::TestFactoryRegistry::getRegistry().makeTest());
+
     bool wasSuccessful = true;
     string test = "";
     int i = getopt.optind;
@@ -245,9 +270,9 @@ int main(int argc, char*argv[]) {
         wasSuccessful = runner.run("");
     }
     else {
-        while (i < argc) {
-            test = string("D4DimensionsTest::") + argv[i++];
-
+        for (; i < argc; ++i) {
+            if (debug) cerr << "Running " << argv[i] << endl;
+            test = D4DimensionsTest::suite()->getName().append("::").append(argv[i]);
             wasSuccessful = wasSuccessful && runner.run(test);
         }
     }
